@@ -1,5 +1,7 @@
 from datetime import datetime
-from typing import Dict, List, Optional, Union
+from typing import Dict, List, Optional, Type, Union
+
+from nicovideo_api_client.constants import FieldType
 
 TypeOp = Dict[str, Union[str, bool, int, List["TypeOp"], "TypeOp"]]
 
@@ -88,17 +90,19 @@ class JsonFilterTerm(JsonFilterOperator):
         super().__init__({})
 
     @staticmethod
-    def set_range_view(
-        from_: Optional[int] = None,
-        to_: Optional[int] = None,
+    def set_range(
+        field_type: FieldType,
+        from_: Optional[Union[int, datetime]] = None,
+        to_: Optional[Union[int, datetime]] = None,
         include_lower: bool = True,
         include_upper: bool = True,
     ) -> "JsonFilterTerm":
         """
-        再生回数が与えられた範囲内かを調べる検索要素。
+        検索フィールドについて、与えられた数値または日付の範囲内かを調べる検索要素。
 
-        :param from_: 再生回数の下限
-        :param to_: 再生回数の上限
+        :param field_type: 検索するフィールド
+        :param from_: 数値の下限または投稿時刻の最古
+        :param to_: 数値の上限または投稿時刻の最新
         :param include_lower: from_ を含むかどうか
         :param include_upper: to_ を含むかどうか
         :return: 絞り込み要素オブジェクト
@@ -108,12 +112,37 @@ class JsonFilterTerm(JsonFilterOperator):
             raise Exception("上限も下限も指定されていません")
         json_: Dict[str, Union[str, bool, int]] = {
             "type": "range",
-            "field": "viewCounter",
+            "field": field_type.value,
         }
-        if from_ is not None:
-            json_["from"] = from_
-        if to_ is not None:
-            json_["to"] = to_
+
+        match field_type:
+            case (
+                FieldType.USER_ID
+                | FieldType.CHANNEL_ID
+                | FieldType.VIEW_COUNTER
+                | FieldType.MYLIST_COUNTER
+                | FieldType.LIKE_COUNTER
+                | FieldType.LENGTH_SECONDS
+                | FieldType.COMMENT_COUNTER
+            ):
+                if from_ is not None:
+                    json_["from"] = JsonFilterTerm._arrange_value(
+                        from_, int, field_type
+                    )
+                if to_ is not None:
+                    json_["to"] = JsonFilterTerm._arrange_value(to_, int, field_type)
+            case (FieldType.START_TIME | FieldType.LAST_COMMENT_TIME):
+                if from_ is not None:
+                    json_["from"] = JsonFilterTerm._arrange_value(
+                        from_, datetime, field_type
+                    )
+
+                if to_ is not None:
+                    json_["to"] = JsonFilterTerm._arrange_value(
+                        to_, datetime, field_type
+                    )
+            case _:
+                raise TypeError(f"{field_type.value}はjson_filterに指定できないフィールドです")
         if include_lower:
             json_["include_lower"] = include_lower
         if include_upper:
@@ -122,32 +151,15 @@ class JsonFilterTerm(JsonFilterOperator):
         return term
 
     @staticmethod
-    def set_range_time(
-        from_: Optional[datetime] = None,
-        to_: Optional[datetime] = None,
-        include_lower: bool = True,
-        include_upper: bool = True,
-    ) -> "JsonFilterTerm":
-        """
-        投稿時刻が与えられた範囲内かを調べる検索要素。
-
-        :param from_: 投稿時刻の最古
-        :param to_: 投稿時刻の最新
-        :param include_lower: from_ を含むかどうか
-        :param include_upper: to_ を含むかどうか
-        :return: 絞り込み要素オブジェクト
-        """
-        term: JsonFilterTerm = JsonFilterTerm()
-        if from_ is None and to_ is None:
-            raise Exception("開始時刻も終了時刻も指定されていません")
-        json_: Dict[str, Union[str, bool]] = {"type": "range", "field": "startTime"}
-        if from_ is not None:
-            json_["from"] = from_.strftime("%Y-%m-%dT%H:%M:%S+09:00")
-        if to_ is not None:
-            json_["to"] = to_.strftime("%Y-%m-%dT%H:%M:%S+09:00")
-        if include_lower:
-            json_["include_lower"] = include_lower
-        if include_upper:
-            json_["include_upper"] = include_upper
-        term.json = json_
-        return term
+    def _arrange_value(
+        value: Union[int, datetime],
+        type_: Union[Type[int], Type[datetime]],
+        field_type: FieldType,
+    ) -> Union[int, str]:
+        if type(value) is type_:
+            if type_ is int:
+                return value
+            elif type_ is datetime:
+                return value.strftime("%Y-%m-%dT%H:%M:%S+09:00")
+        else:
+            raise TypeError(f"フィールド {field_type.value} には {type_} が指定されるべきです")
